import os

PROJECT_ROOT_PATH = os.getcwd()
REPORT_PATH = os.path.join(PROJECT_ROOT_PATH, 'reports')
REPORT_SCREENSHOTS_PATH = os.path.join(REPORT_PATH, 'screenshots')
OUTPUT_PATH = os.path.join(PROJECT_ROOT_PATH, 'output')
SCREENSHOTS_PATH = os.path.join(OUTPUT_PATH, 'screenshots')
